"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var src_exports = {};
__export(src_exports, {
  DNS: () => DNS
});
module.exports = __toCommonJS(src_exports);
var import_pure_cat = require("pure-cat");
var import_node_fetch = __toESM(require("node-fetch"));
const resolvers = {
  Google: "https://dns.google.com/resolve",
  Cloudflare: "https://cloudflare-dns.com/dns-query"
};
const record_types = ["A", "AAAA", "CNAME", "MX", "NS", "PTR", "SRV", "TXT"];
async function lookup(domain, type, resolver) {
  const url = `${resolvers[resolver]}?name=${domain}${type ? `&type=${type}` : ""}`;
  const res = (0, import_node_fetch.default)(url, { headers: { accept: "application/dns-json" } });
  const json = await res.then((r) => r.json());
  return json.Answer;
}
const command = new import_pure_cat.Command("dns", "Look up a DNS record").addStringOption(
  (option) => option.setName("domain").setDescription("The domain to look up").setRequired(true)
).addStringOption(
  (option) => option.setName("type").setDescription("The type of record to look up").addChoices(...record_types.map((name) => ({ name, value: name }))).setRequired(false)
).addStringOption(
  (option) => option.setName("resolver").setDescription("The resolver to use").addChoices(...Object.keys(resolvers).map((name) => ({ name, value: name }))).setRequired(false)
).handle(async (interaction) => {
  var _a, _b;
  const guild = interaction.guild;
  if (!guild) {
    return;
  }
  const domain = interaction.options.get("domain", true).value;
  const type = ((_a = interaction.options.get("type", false)) == null ? void 0 : _a.value) || "";
  const resolver = ((_b = interaction.options.get("resolver", false)) == null ? void 0 : _b.value) || "Cloudflare";
  const result = lookup(domain, type, resolver);
  await interaction.reply(`Using ${resolver} to look up ${type} records for ${domain} ...`);
  try {
    await interaction.editReply(
      "```json\n" + JSON.stringify(await result || `No results for ${domain}`, null, 4) + "\n```"
    );
  } catch (err) {
    await interaction.editReply(`Failed to look up ${domain} ${err}`);
  }
});
class DNS extends import_pure_cat.Module {
  commands = [];
  triggers = [];
  constructor({ slash = true, triggers = [/!dns ([^\s]+)\s*([^\s]*)\s*([^\s]*)/] } = {}, bot) {
    super(bot);
    if (slash) {
      this.commands.push(command);
    }
    this.triggers = triggers;
  }
  async messageCreate(bot, message) {
    let matched = null;
    for (const trigger of this.triggers) {
      matched = trigger.exec(message.content);
      if (matched) {
        break;
      }
    }
    const guild = message.guild;
    if (matched && guild) {
      const domain = matched[1];
      const type = matched[2];
      const resolver = Object.keys(resolvers).includes(matched[3]) ? matched[3] : "Cloudflare";
      const result = lookup(domain, type, resolver);
      const reply = await message.reply(
        `Using ${resolver} to look up ${type} records for ${domain} ...`
      );
      try {
        await reply.edit(
          "```json\n" + JSON.stringify(await result || `No results for ${domain}`, null, 4) + "\n```"
        );
      } catch (err) {
        await reply.edit(`Failed to look up ${domain} ${err}`);
      }
    }
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DNS
});
